#!/bin/sh

#
# issue.sh - genere un zoli fichier issue
#
# Usage : issue.sh <fic>
#
# Description :
# issue.sh prend en parametre le fichier <fic> et genere sur la sortie
# standart le fichier destine a etre /etc/issue. Le texte est centre et
# entoure d'un cadre dont l'epaisseur et la couleur peuvent etre modifies
# directement au debut du script (variables NombreColones, EspaceCadre,
# EspaceBordure, CouleurBordure, CouleurTexte et CouleurFondCadre).
#

#
# Nombre de colones sur lesquelles le fichier doit etre affiche
#

NombreColones=78

#
#  Espace entre la fenetre et le bord exterieur du cadre
#

EspaceCadre="  "

#
# Epaisseur du cadre
#

EspaceBordure="    "

#
# Couleur de la bordure
#

CouleurBordure="\033[34;44m"

#
# Couleur du texte
#

CouleurTexte="\033[34;32m"

#
# Couleur de fond du cadre
#

CouleurFondCadre="\033[34;40m"

#Texte="Bienvenue sur mdecore's server Linux 1.0"

#
# NE RIEN EDITER AU DELA DE CETTE LIGNE
#

[ $# -ne 1 ] && echo >&2 "Usage : `basename $0` <fic>" && exit 1

echo "$1" | grep "^\/" > /dev/null && Fic="$1" || Fic="`pwd`/$1"

cd `dirname $0`

if test -z "$NombreColones" ; then
    set -- `stty size 2>/dev/null`
    NombreColones=$2
fi

if test $NombreColones -eq 0 ; then
    NombreColones=40
fi

AfficheRegle ()
{
i=1
while [ $i -le 79 ]
do
    case `expr $i % 5` in
        0)  echo -n "." ;;
        1)  echo -n "1" ;;
        2)  echo -n "2" ;;
        3)  echo -n "3" ;;
        4)  echo -n "4" ;;
        *)  echo -n " " ;; 
    esac
    i=`expr $i + 1`
done
}

CouleurCadre_g="$EspaceCadre$CouleurBordure$EspaceBordure$CouleurFondCadre"
CouleurCadre_d="$CouleurBordure$EspaceBordure\033[0m$EspaceCadre"

[ `expr $NombreColones % 2` -eq 1 ] && NombreColones=`expr $NombreColones - 1`

#
# Calculs d'espace disponible pour centrer le cadre, le texte dans le cadre...
#
# Par la suite, les termes :
#     - fenetre designe la console (ou le xterm, ...) ;
#     - cadre designe le cadre exterieur dans lequel le texte sera mis ;
#     - bordure designe la bordure du cadre.
#
#                             NombreColones 
# <---------------------------------------------------------------------->
# +----------------------------------------------------------------------+
# |  +- EspaceCadre (taille TailleFen2Cadre)                             |
# |  |   +- EspaceBordure (taille TailleBordure)                         |
# |  |   |    EspaceFen2Cadre (taille TailleEspaceCadre)                 |
# |  |   |                          |                                    |
# |  v   v                          v                                    |
# |<---><-><---------------------------------------------------->        |
# |     +-------------------------------------------------------+        |
# |     | +---------------------------------------------------+ |        |
# |     | |                                                   | |        |
# |     | |                 Texte centre ...                  | |        |
# |     | |                                                   | |        |
# |     | +---------------------------------------------------+ |        |
# |     +-------------------------------------------------------+        |
# |                                                                      |
# +----------------------------------------------------------------------+
#
#
# Nombre d'espaces entre la fenetre et le bord exterieur du cadre
#

#TailleFen2Cadre=`expr \`echo "$EspaceCadre" | wc -c\` + \`echo "$EspaceCadre" | wc -c \``
TailleFen2Cadre=`expr \`echo "$EspaceCadre" | wc -c\` - 1`

#
# Nombre d'espaces entre de la bordure
#

TailleBordure=`expr \`echo "$EspaceBordure" | wc -c\` - 1`

#
# Nombre d'espaces entre la fenetre et l'interieur du cadre
#

TailleFen2Bordure=`expr $TailleFen2Cadre + $TailleBordure`

#
# Nombre d'espaces disponibles pour afficher le texte dans le cadre
#

TailleEspaceCadre=`expr $NombreColones - $TailleFen2Bordure \* 2`

#EspaceFen2Cadre=""
EspaceFen2CadreTete=""

#echo "TailleEspaceCadre $TailleEspaceCadre"

#
# La tete du cadre est une suite de TailleEspaceCadre espaces
#

i=0
while [ $i -lt $TailleEspaceCadre ]
do
#    [ $i -lt $TailleEspaceCadre ] && EspaceFen2CadreTete="$EspaceFen2CadreTete "
    EspaceFen2Cadre="$EspaceFen2Cadre "
    i=`expr $i + 1`
done

#
#
#

#EspaceFen2Cadre="$EspaceBordure$EspaceFen2CadreTete$EspaceBordure"
#EspaceFen2Cadre="$EspaceFen2CadreTete"

#echo "$EspaceFen2Cadre" | wc -c
#echo "$EspaceFen2CadreTete" | wc -c

#
# Affichage du haut du cadre
#

echo
#AfficheRegle
echo -e "$EspaceCadre$CouleurBordure$EspaceBordure$EspaceFen2Cadre$EspaceBordure\033[0m$EspaceCadre"
#AfficheRegle
echo -e "$EspaceCadre$CouleurBordure$EspaceBordure$CouleurFondCadre$EspaceFen2Cadre$CouleurBordure$EspaceBordure\033[0m$EspaceCadre"

#
# Affichage du texte
#

#echo "$Texte" | ./indent.sh `expr $TailleEspaceCadre - 2` | while read ligne
#echo "$Texte" | while read ligne
./indent.sh `expr $TailleEspaceCadre - 2` < $Fic | while read ligne
do

#
# Nombre de caracteres occuppes par la ligne a afficher
#

    NombreCar=`expr \`echo "$ligne" | wc -c\` - 1`
#echo "NombreCar : $NombreCar"

#
# Taille de l'espace de chaque cote du texte a afficher
#

    #TailleEspace=`expr $NombreColones - $NombreCar - $TailleFen2Bordure`
    TailleEspace=`expr $TailleEspaceCadre - $NombreCar`
    TailleEspace=`expr $TailleEspace / 2`
#echo "TailleEspace : $TailleEspace"
    Espace_g=""
    i=1
    while [ $i -le `expr $TailleEspace - 1` ]
    do
        Espace_g="$Espace_g "
        i=`expr $i + 1`
#        Espace_d="$Espace_d "
    done
#set -x
    if [ `expr $NombreCar % 2` -eq 1 ]
    then
        Espace_g="$Espace_g "
        Espace_d="$Espace_g "
    else
        Espace_g="$Espace_g "
        Espace_d="$Espace_g"
    fi

#set +x
#echo "$Espace_g" | wc -c
#echo "$Espace_d" | wc -c

#echo Taille Espace : `echo "$Espace" | wc -c`
#echo "$CouleurCadre_g$CouleurTexte$Espace$ligne$Espace$CouleurCadre_d"
#set -x
#echo

#
# La ligne de texte est affichee
#

#AfficheRegle
    echo -e "$CouleurCadre_g$CouleurTexte$Espace_g$ligne$Espace_d$CouleurCadre_d"
#set +x
done

#echo -e "$CouleurCadre  $CouleurTexte  Salut"

#
# Affichage du bas du cadre
#

#echo -e "$EspaceCadre\033[34;44m$EspaceBordure$EspaceFen2Cadre$EspaceBordure\033[0m$EspaceCadre"
#echo -e "$EspaceCadre\033[34;44m$EspaceBordure\033[34;40m$EspaceFen2Cadre\033[34;44m$EspaceBordure\033[0m$EspaceCadre"

#echo "$EspaceFen2Cadre" | wc -c
echo -e "$EspaceCadre$CouleurBordure$EspaceBordure$CouleurFondCadre$EspaceFen2Cadre$CouleurBordure$EspaceBordure\033[0m$EspaceCadre"
echo -e "$EspaceCadre$CouleurBordure$EspaceBordure$EspaceFen2Cadre$EspaceBordure\033[0m$EspaceCadre"

echo

